<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kn_IN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="374"/>
        <source>Cannot generate random number by TPM</source>
        <translation>ಟಿಪಿಎಂ ಮೂಲಕ ಅಂಕೆಯನ್ನು ಉತ್ಪಾದಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="377"/>
        <source>No available encrypt algorithm.</source>
        <translation>ಪ್ರಸ್ತುತ ಲಭ್ಯವಿರುವ ಶಾಖಿಸುವ ಅಲ್ಗಾರಿದಮ್ ಇಲ್ಲ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="380"/>
        <source>TPM encrypt failed.</source>
        <translation>ಟಿಪಿಎಂ ಶಾಖಿಸುವ ವಿಫಲವಾಯಿತು.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="383"/>
        <source>TPM is locked.</source>
        <translation>ಟಿಪಿಎಂ ಬಂದು ಸೇರಿದೆ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="411"/>
        <source>Confirm encrypt %1?</source>
        <translation>%1 ಶಾಖಿಸುವ ಸೂಚಿಸುವ?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="414"/>
        <source>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</source>
        <translation>ಪ್ರಸ್ತುತ ಪಾರ್ಷಿಷನ್ ಶಾಖಿಸುವ ಸೂಚನೆಯಲ್ಲಿದೆ ಮತ್ತು ಶಾಖಿಸುವ ಪ್ರಕ್ರಿಯೆಯಲ್ಲಿ ರದ್ದುಗೊಳಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ, ಶಾಖಿಸುವ ಸೂಚನೆಯನ್ನು ನಿರ್ಧರಿಸಿ.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="421"/>
        <source>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</source>
        <translation>* ಪಾರ್ಷಿಷನ್ ಶಾಖಿಸುವ ನಂತರ, ಸಿಸ್ಟಮ್ ಕಡಿಮೆ ವೇರಿಯನ್ಸ್ಗೆ ಹಿಂತಿರುಗಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ, ಶಾಖಿಸುವ ಸೂಚನೆಯನ್ನು ನಿರ್ಧರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="432"/>
        <source>Cancel</source>
        <translation>ರದ್ದುಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="433"/>
        <source>Confirm and Reboot</source>
        <translation>ನಿರ್ಧರಿಸಿ ಮತ್ತು ಪುನರಾವರ್ತನೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="434"/>
        <source>Confirm</source>
        <translation>ನಿರ್ಧರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="444"/>
        <source>Decrypt %1?</source>
        <translation>%1 ಅನ್ಶಾಖಿಸುವ?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="445"/>
        <source>Decryption can take a long time, so make sure power is connected until the decryption is complete.</source>
        <translation>ಅನ್ಶಾಖಿಸುವ ಪ್ರಕ್ರಿಯೆಯು ಹೆಚ್ಚು ಸಮಯ ತೆಗೆದುಕೊಳ್ಳಬಹುದು, ಅನ್ಶಾಖಿಸುವ ಪೂರ್ಣಗೊಳಿಸಲು ತನಕ ಬಿಜೆಟ್ ಸಂಪರ್ಕದಲ್ಲಿದ್ದು ಇರಿಸಿಕೊಳ್ಳಿ.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::ChgPassphraseDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="18"/>
        <source>passphrase</source>
        <translation>ಪಾಸ್ಫ್ರೇಸ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="20"/>
        <source>PIN</source>
        <translation>ಪಿಇಎನ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="109"/>
        <source>Recovery key</source>
        <translation>ಪುನರಾವರ್ತನೆ ಕೀ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="171"/>
        <source>Validate with %1</source>
        <translation>%1 ಅನ್ನು ಸರಿದೂrawಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="172"/>
        <source>Please input recovery key</source>
        <translation>ಪುನರಾವರ್ತನೆ ಕೀಯನ್ನು ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="174"/>
        <source>Old %1</source>
        <translation>ಉಳ್ಳ %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="70"/>
        <source>New %1</source>
        <translation>ಹೊಸ %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="56"/>
        <source>Modify %1</source>
        <translation>%1 ಸರಿದೂರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="67"/>
        <source>Please enter %1 again</source>
        <translation>%1 ಅನ್ನು ಮತ್ತೆ ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="71"/>
        <source>Repeat %1</source>
        <translation>%1 ಪುನರಾವರ್ತನೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="77"/>
        <source>Cancel</source>
        <translation>ರದ್ದುಗೊಳಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="78"/>
        <source>Confirm</source>
        <translation>ನಿರ್ಧರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="101"/>
        <source>%1 cannot be empty</source>
        <translation>'%1 ಖಾಲಿಯಾಗಿರಬಾರದು'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>ಪುನರಾವರ್ತನೆ ಕೀ ಸರಿಯಾಗಿದೆ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="140"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="145"/>
        <source>%1 inconsistency</source>
        <translation>'%1 ಅಸಮಾನತೆ'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="177"/>
        <source>Validate with recovery key</source>
        <translation>ಪುನರಾವರ್ತನೆ ಕೀಯನ್ನು ಸರಿದೂರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DecryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>Validate with %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="56"/>
        <source>Please input %1 to decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="103"/>
        <source>Decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="51"/>
        <source>Please input recovery key to decrypt device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="57"/>
        <source>Validate with recovery key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="79"/>
        <source>Passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="81"/>
        <source>Recovery key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="82"/>
        <source>%1 cannot be empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="87"/>
        <source>Recovery key is not valid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="111"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DiskEncryptMenuScene</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="148"/>
        <source>Unlock encrypted partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="152"/>
        <source>Cancel partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="156"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="157"/>
        <source>Changing the encryption %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="161"/>
        <source>Continue partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="165"/>
        <source>Continue partition decryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="169"/>
        <source>Enable partition encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="225"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="226"/>
        <source>Cannot resolve passphrase from TPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="248"/>
        <source>PIN error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="276"/>
        <source>Change passphrase failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="525"/>
        <source>Unlock device failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="526"/>
        <source>Wrong passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="544"/>
        <source>Mount device failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>unmount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="588"/>
        <source>Encrypt failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="589"/>
        <source>Cannot %1 device %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="673"/>
        <source>Reboot to continue encrypt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="674"/>
        <source>Reboot to finish decrypt</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="130"/>
        <source>Unlocked by passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="157"/>
        <source>In special cases such as forgetting the password or the encryption hardware is damaged, you can decrypt the encrypted partition with the recovery key, please export it to a non-encrypted partition and keep it in a safe place!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="172"/>
        <source>Please select a non-encrypted partition as the key file export path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="192"/>
        <source>Passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="194"/>
        <source>%1 cannot be empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="225"/>
        <source>%1 inconsistency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="236"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="241"/>
        <source>Recovery key export path is not exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="248"/>
        <source>Please export to an external device such as a non-encrypted partition or USB flash drive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="253"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="265"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="421"/>
        <source>TPM is locked and cannot be used for partition encryption. Please cancel the TPM password or choose another unlocking method.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="423"/>
        <source>TPM error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="426"/>
        <source>TPM status error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="316"/>
        <source>Please continue to encrypt partition %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="321"/>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="320"/>
        <source>Export Recovery Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="329"/>
        <source>Set %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="330"/>
        <source>Repeat %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="336"/>
        <source>passphrase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="340"/>
        <source>Access to the partition will be unlocked using a passphrase.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="347"/>
        <source>Access to the partition will be unlocked using the TPM security chip and PIN.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="350"/>
        <source>Access to the partition will be automatically unlocked using the TPM security chip, no passphrase checking is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="332"/>
        <source>Please enter the %1 again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="110"/>
        <source>Unlock type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="131"/>
        <source>Use TPM+PIN to unlock on this computer (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="132"/>
        <source>Automatic unlocking on this computer by TPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="220"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Confirm encrypt</source>
        <translation>ಶಾಸ್ತ್ರೀಯ ಗುಪ್ತಪಡಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="343"/>
        <source>PIN</source>
        <translation>ಪಿಎನ್</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptProgressDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="54"/>
        <source>Confirm</source>
        <translation>ಆಗಮನ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="63"/>
        <source>Re-export the recovery key</source>
        <translation>ಪುನರುತ್ಪತ್ತಿ ಮಾಡಿ ಪುನರುತ್ಪತ್ತಿ ಮಾಡು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="67"/>
        <source>*Recovery key saving failed, please re-save the recovery key to a non-encrypted partition and keep it in a safe place!</source>
        <translation>*ಪುನರುತ್ಪತ್ತಿ ಮಾಡುವ ಮುಖ್ಯ ಮಾಹಿತಿ ಬೆಂಬಲದಲ್ಲಿ ಉಳ್ಳಿರುವುದಿಲ್ಲ, ಬೆಂಬಲದಲ್ಲಿರುವ ಮುಖ್ಯ ಮಾಹಿತಿಯನ್ನು ಗುಪ್ತಪಡಿಸಲಾದ ಪಾರ್ಷನ್ಗೆ ಪುನರುತ್ಪತ್ತಿ ಮಾಡಿ ಅದನ್ನು ಅದೃಶ್ಯ ಸ್ಥಳದಲ್ಲಿ ಇಟ್ಟುಕೊಳ್ಳಿ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="82"/>
        <source>Error</source>
        <translation>ಅಂಶ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="143"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>ಪುನರುತ್ಪತ್ತಿ ಮಾಡುವ ಮುಖ್ಯ ಮಾಹಿತಿಯನ್ನು ಹಾರ್ಡ್ವೇರ್ ಅಥವಾ ಅಗತ್ಯವಿರುವ ಅಂಶಗಳನ್ನು ಬಳಸಿ ಇಟ್ಟುಕೊಳ್ಳಲಾಗಿಲ್ಲ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="148"/>
        <source>Recovery key export path is not exists!</source>
        <translation>ಪುನರುತ್ಪತ್ತಿ ಮಾಡುವ ಮುಖ್ಯ ಮಾಹಿತಿಯನ್ನು ಹಾರ್ಡ್ವೇರ್ ಅಥವಾ ಅಗತ್ಯವಿರುವ ಅಂಶಗಳನ್ನು ಬಳಸಿ ಇದು ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="154"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>ಈ ಪಾರ್ಷನ್ ಓದಲು ಮಾತ್ರ ಸಾಧ್ಯ, ಅದೃಶ್ಯ ಪಾರ್ಷನ್ಗೆ ಪುನರುತ್ಪತ್ತಿ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="167"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>ಈ ಪಾರ್ಷನ್ ಗುಪ್ತಪಡಿಸಲಾಗಿದೆ, ಅದೃಶ್ಯ ಪಾರ್ಷನ್ಗೆ ಅಥವಾ USB ಕಾರ್ಡ್ ಹೀಗೆ ಅಗತ್ಯವಿರುವ ಬಾಹ್ಯ ಯಂತ್ರದಲ್ಲಿ ಪುನರುತ್ಪತ್ತಿ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="183"/>
        <source>Cannot create recovery key file!</source>
        <translation>ಪುನರುತ್ಪತ್ತಿ ಮಾಡುವ ಮುಖ್ಯ ಮಾಹಿತಿಯನ್ನು ಅಂಶ ಸೃಷ್ಟಿಸಲಾಗಿಲ್ಲ!</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EventsHandler</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="424"/>
        <source>Preencrypt done</source>
        <translation>ಪ್ರಾಥಮಿಕ ಗುಪ್ತಪಡಿಸುವುದು ಮುಗಿದಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="425"/>
        <source>Device %1 has been preencrypt, please reboot to finish encryption.</source>
        <translation>ಯಂತ್ರ %1 ಪ್ರಾಥಮಿಕ ಗುಪ್ತಪಡಿಸಲಾಗಿದೆ, ಗುಪ್ತಪಡಿಸುವುದನ್ನು ಮುಗಿಸಲು ಪುನರಾರಂಭಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="431"/>
        <source>Preencrypt failed</source>
        <translation>ಪ್ರಾಥಮಿಕ ಗುಪ್ತಪಡಿಸುವುದು ಅಸಾಧ್ಯ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="432"/>
        <source>Device %1 preencrypt failed, please see log for more information.(%2)</source>
        <translation>ಯಂತ್ರ %1 ಪ್ರಾಥಮಿಕ ಗುಪ್ತಪಡಿಸುವುದು ಅಸಾಧ್ಯ, ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗಾಗಿ ದಾಖಲೆಯನ್ನು ನೋಡಿ(%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="460"/>
        <source>Wrong passpharse or PIN</source>
        <translation>ಅನುಮಾನಾಸ್ಪದ ಪಾಸ್ಪ್ರೇಸ್ ಅಥವಾ ಪಿಎನ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="496"/>
        <source>passphrase</source>
        <translation>ಪಾಸ್ಪ್ರೇಸ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="499"/>
        <source>PIN</source>
        <translation>ಪಿಎನ್</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="506"/>
        <source>Change %1 done</source>
        <translation>%1 ಬದಲಾವಣೆ ಮುಗಿದಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="507"/>
        <source>%1's %2 has been changed</source>
        <translation>'%1' ದ %2 ಅನ್ನು ಬದಲಾಯಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="512"/>
        <source>Change %1 failed</source>
        <translation>%1 ಬದಲಾವಣೆ ಅಸಾಧ್ಯ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="513"/>
        <source>Wrong %1</source>
        <translation>ಅನುಮಾನಾಸ್ಪದ %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="518"/>
        <source>Device %1 change %2 failed, please see log for more information.(%3)</source>
        <translation>ಯಂತ್ರ %1 ಬದಲಾವಣೆ %2 ಅಸಾಧ್ಯ, ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗಾಗಿ ದಾಖಲೆಯನ್ನು ನೋಡಿ(%3)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="180"/>
        <source>Encrypt done</source>
        <translation>ಗುಪ್ತಪಡಿಸುವುದು ಮುಗಿದಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="181"/>
        <source>Device %1 has been encrypted</source>
        <translation>ಯಂತ್ರ %1 ಗುಪ್ತಪಡಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="185"/>
        <source>Encrypt failed</source>
        <translation>ಗುಪ್ತಪಡಿಸುವುದು ಅಸಾಧ್ಯ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="186"/>
        <source>Device %1 encrypt failed, please see log for more information.(%2)</source>
        <translation>ಯಂತ್ರ %1 ಗುಪ್ತಪಡಿಸುವುದು ಅಸಾಧ್ಯ, ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗಾಗಿ ದಾಖಲೆಯನ್ನು ನೋಡಿ(%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="285"/>
        <source>%1 is under encrypting...</source>
        <translation>'%1 ಗುಪ್ತಪಡಿಸುವುದು ನಡೆಯುತ್ತಿದೆ...'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="286"/>
        <source>The encrypting process may have system lag, please minimize the system operation</source>
        <translation>ಗುಪ್ತಪಡಿಸುವುದು ಪ್ರಕ್ರಿಯೆಯಲ್ಲಿ ಸಿಸ್ಟಂ ಸ್ಥಿತಿಯಲ್ಲಿ ಕೆಲವು ವಿಳಂಬಗಳನ್ನು ಹೊಂದಬಹುದು, ಸಿಸ್ಟಂ ಕಾರ್ಯಗಳನ್ನು ಕಡಿಮೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="305"/>
        <source>%1 is under decrypting...</source>
        <translation>'%1 ಗುಪ್ತಪಡಿಸುವುದು ನಡೆಯುತ್ತಿದೆ...'</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="306"/>
        <source>The decrypting process may have system lag, please minimize the system operation</source>
        <translation>ಪ್ರಕ್ರಿಯೆಯಲ್ಲಿ ಸಿಸ್ಟಂ ಲಾಗ್ ಇರಬಹುದು, ಸಿಸ್ಟಂ ಪರಿಕರ್ಮವನ್ನು ಕಡಿಮೆ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>Error</source>
        <translation>ಖಾತ್ರಿಯಿಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="452"/>
        <source>Decrypt done</source>
        <translation>ಗುಪ್ತಪದಗಳನ್ನು ಗುರುತಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="453"/>
        <source>Device %1 has been decrypted</source>
        <translation>ಯಂತ್ರ %1 ಗುಪ್ತಪದಗಳನ್ನು ಗುರುತಿಸಲಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="459"/>
        <source>Decrypt disk</source>
        <translation>ಡಿಸ್ಕ್ ಗುರುತಿಸಲು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="463"/>
        <source>Decrypt failed</source>
        <translation>ಗುರುತಿಸುವುದು ವಿಫಲವಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="464"/>
        <source>Device %1 is under encrypting, please decrypt after encryption finished.</source>
        <translation>ಯಂತ್ರ %1 ಗುಪ್ತಪದಗಳನ್ನು ಸುರಕ್ಷತೆಗೊಳಪಡುತ್ತಿದೆ, ಗುರುತಿಸಲು ಕುರುಹು ಮುಗಿಯಿತು ನಂತರ ಗುರುತಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="469"/>
        <source>Device %1 Decrypt failed, please see log for more information.(%2)</source>
        <translation>ಯಂತ್ರ %1 ಗುರುತಿಸುವುದು ವಿಫಲವಾಯಿತು, ಹೆಚ್ಚಿನ ಮಾಹಿತಿಗಾಗಿ ಲಾಗ್ ನೋಡಿ(%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="547"/>
        <source>Device is not fully decrypted, please finish decryption before access.</source>
        <translation>ಯಂತ್ರ ಪೂರ್ತಿ ಗುರುತಿಸಲಾಗಿಲ್ಲ, ಪ್ರವೇಶ ಮಾಡುವ ಮೊದಲು ಗುರುತಿಸುವುದನ್ನು ಮುಗಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="554"/>
        <source>Unlocking device failed</source>
        <translation>ಯಂತ್ರವನ್ನು ಅಂಗೀಕರಿಸುವುದು ವಿಫಲವಾಯಿತು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="555"/>
        <source>Please click the right disk menu "Continue partition encryption" to complete partition encryption.</source>
        <translation>ಪಾರ್ಟಿಷನ್ ಗುಪ್ತಪದಗಳನ್ನು ಮುಗಿಸಲು ಬಲ ಡಿಸ್ಕ್ ಮೆನು "ಪಾರ್ಟಿಷನ್ ಗುಪ್ತಪದ ಮುಂದುವರೆಸಿ" ಅನ್ನು ಕ್ಲಿಕ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>TPM status is abnormal, please use the recovery key to unlock it</source>
        <translation>TPM ಅನುಪಸ್ಥಿತಿಯನ್ನು ಅಸಮಾನ್ಯವಾಗಿದೆ, ಅದನ್ನು ಅಂಗೀಕರಿಸಲು ಪುನರುತ್ಪಾದನೆ ಕೀ ಬಳಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="357"/>
        <source>Wrong PIN</source>
        <translation>ಅಲ್ಲಿ ಸುಲಭ ಸಂಖ್ಯೆ ತಪ್ಪಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="359"/>
        <source>Wrong passphrase</source>
        <translation>ಅಲ್ಲಿ ಪಾಸ್ಪ್ರೆಫ್ರೇಸ್ ತಪ್ಪಾಗಿದೆ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="361"/>
        <source>TPM error</source>
        <translation>TPM ತಪ್ಪು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="363"/>
        <source>Please use recovery key to unlock device.</source>
        <translation>ಯಂತ್ರವನ್ನು ಅಂಗೀಕರಿಸಲು ಪುನರುತ್ಪಾದನೆ ಕೀ ಬಳಸಿ.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::UnlockPartitionDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>ರದ್ದು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="52"/>
        <source>Unlock</source>
        <translation>ಅಂಗೀಕರಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="81"/>
        <source>Unlock encryption partition</source>
        <translation>ಗುಪ್ತಪದ ಪಾರ್ಟಿಷನ್ ಅಂಗೀಕರಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="85"/>
        <source>Unlock by recovery key</source>
        <translation>ಪುನರುತ್ಪಾದನೆ ಕೀ ಬಳಸಿ ಅಂಗೀಕರಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="90"/>
        <source>Unlock by passphrase</source>
        <translation>ಪಾಸ್ಪ್ರೆಫ್ರೇಸ್ ಬಳಸಿ ಅಂಗೀಕರಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="91"/>
        <source>Unlock by PIN</source>
        <translation>ಸುಲಭ ಸಂಖ್ಯೆ ಬಳಸಿ ಅಂಗೀಕರಿಸು</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="93"/>
        <source>Please input recovery key to unlock device</source>
        <translation>ಯಂತ್ರವನ್ನು ಅಂಗೀಕರಿಸಲು ಪುನರುತ್ಪಾದನೆ ಕೀ ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="99"/>
        <source>Please input passphrase to unlock device</source>
        <translation>ಯಂತ್ರವನ್ನು ಅಂಗೀಕರಿಸಲು ಪಾಸ್ಪ್ರೆಫ್ರೇಸ್ ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="102"/>
        <source>Please input PIN to unlock device</source>
        <translation>ಯಂತ್ರವನ್ನು ಅಂಗೀಕರಿಸಲು ಸುಲಭ ಸಂಖ್ಯೆ ನಮೂದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>ಪುನರುತ್ಪಾದನೆ ಕೀ ಅನುವು ಸೂಚಿಸುವುದಿಲ್ಲ!</translation>
    </message>
</context>
</TS>
